pub struct ServoLayoutElement<'dom> {
pub(super) element: LayoutDom<'dom, Element>,
pub(super) pseudo_element_chain: PseudoElementChain,
}Expand description
An implementation of LayoutElement for Servo’s script crate.
Fields
element: LayoutDom<'dom, Element>The wrapped private DOM Element.
pseudo_element_chain: PseudoElementChainThe possibly nested PseudoElementChain for this element.
Implementations
Sourceimpl<'dom> ServoLayoutElement<'dom>
impl<'dom> ServoLayoutElement<'dom>
pub(super) fn is_html_element(&self) -> bool
Sourcepub(super) fn shadow_root(&self) -> Option<ServoDangerousStyleShadowRoot<'dom>>
pub(super) fn shadow_root(&self) -> Option<ServoDangerousStyleShadowRoot<'dom>>
The shadow root that this ServoLayoutElement is a host of, if it has one.
Note: This should not be exposed to layout as it allows access to an ancestor element.